@@ -1,9 +1,8 @@
 load_test_games <- function(){
-  g <- nflseedR::load_sharpe_games()
+  g <- nflreadr::load_schedules(2014:2019)
 
   if (!nrow(g) > 0) return(tibble::tibble())
 
-  g %>%
-    dplyr::filter(season %in% 2014:2019) %>%
+  g |>
     dplyr::select(sim = season, game_type, week, away_team, home_team, result)
 }
